API Docs
=============================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   array
   vector
   matrix
   metrics
   linear_systems
   orth
   svdpack
   subspaces
   affine
   geom2d
   standard
   data
   util
